package VMOMI::HostNasVolumeSecurityType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
